#!/usr/bin/env ruby

require 'mechanize'
require 'blogbot/extraction'
require 'blogbot/memorization'
require 'blogbot/navigation'
require 'blogbot/reflection'

# Make a new blogbot that can scan pages and extract the most popular links!
class Blogbot
  include Extraction
  include Memorization
  include Navigation
  include Reflection

  attr_accessor(
    :agent,
    :article_link,
    :blog_link,
    :current_element,
    :current_page,
    :indicator,
    :parent,
    :posts_url,
    :target_url
  )

  def set_agent
    self.agent = Mechanize.new { |a| a.user_agent_alias = 'Mac Safari' }
  end

  def initialize
    puts 'Powering up the rubatron generators!!'
    set_agent
    @current_page = nil
    @current_element = nil
    @popular_links = []
    @indicator = nil
  end

  # GET a page using Mechanize and set to current page.
  def scan(url)
    @target_url = url
    @current_page = @agent.get(@target_url)
  end

  def reset
    set_agent
    @current_page = nil
    @current_element = nil
    @popular_links = []
    @indicator = nil
  end

  def ignorance_error
    fail "Sorry, either there are no popular links present
          or this bot isn't smart enough to extract this site yet\n"
  end
end
